@@ -1,3 +1,3 @@
 #!/usr/bin/env python3
-from fast_eval import main
+from .fast_eval.py import main
 main()
